@@ -3,7 +3,7 @@ use crate::crud::CRUDTable;
 use crate::rbatis::Rbatis;
 use crate::DriverType;
 use rbatis_core::Error;
-use serde_json::Value;
+use bson::Bson;
 use std::fmt::{Debug, Display};
 
 /// sql intercept
@@ -18,7 +18,7 @@ pub trait SqlIntercept: Send + Sync + Debug {
         &self,
         rb: &Rbatis,
         sql: &mut String,
-        args: &mut Vec<serde_json::Value>,
+        args: &mut Vec<bson::Bson>,
         is_prepared_sql: bool,
     ) -> Result<(), crate::core::Error>;
 }
@@ -31,7 +31,7 @@ impl SqlIntercept for RbatisLogFormatSqlIntercept {
         &self,
         rb: &Rbatis,
         sql: &mut String,
-        args: &mut Vec<Value>,
+        args: &mut Vec<Bson>,
         is_prepared_sql: bool,
     ) -> Result<(), Error> {
         let driver_type = rb.driver_type()?;
@@ -64,7 +64,7 @@ impl SqlIntercept for BlockAttackDeleteInterceptor {
         &self,
         rb: &Rbatis,
         sql: &mut String,
-        args: &mut Vec<Value>,
+        args: &mut Vec<Bson>,
         is_prepared_sql: bool,
     ) -> Result<(), Error> {
         let sql = sql.trim();
@@ -89,7 +89,7 @@ impl SqlIntercept for BlockAttackUpdateInterceptor {
         &self,
         rb: &Rbatis,
         sql: &mut String,
-        args: &mut Vec<Value>,
+        args: &mut Vec<Bson>,
         is_prepared_sql: bool,
     ) -> Result<(), Error> {
         let sql = sql.trim();
