@@ -117,41 +117,58 @@ macro_rules! make_table_field_map_btree {
     }};
 }
 
-
-/**
-   this macro allow gen column fn
-    #[crud_table]
-    #[derive(Clone, Debug)]
-    make_column_fn!(
-      pub struct BizActivity {
-         pub id: Option<String>
-     }
-   );
-  println!("{}",BizActivity::id());
-**/
-
-#[allow(unused_macros)]
-#[macro_export]
-macro_rules! make_column_fn {
-    (pub struct $t:ty{ $(pub $key:ident:$value:expr$(,)?)+ }) => {
-           pub struct $t{
-                   $(pub $key:$value,)+
-           }
-           impl $t{
-                       $(
-                         #[inline]
-                         pub fn $key()->&'static str{
-                             stringify!($key)
-                         }
-                       )+
-               }
-        }
-}
-
 #[allow(unused_macros)]
 #[macro_export]
 macro_rules! as_bson {
     ($key:expr) => {
         bson::to_bson($key).unwrap_or_default()
     }
+}
+
+/// Used to simulate enumerations to improve code maintainability.
+/// this is return &str data
+/// for example:
+/// let name=field_name!(BizActivity.id);
+/// rb.new_wrapper().eq(field_name!(BizActivity.id),"1")
+///
+#[allow(unused_macros)]
+#[macro_export]
+macro_rules! field_name {
+    ($t:ident.$field:ident) => {
+        {
+           if false{|a:$t|{a.$field};}
+           stringify!($field).trim_start_matches("r#")
+        }
+    };
+}
+
+
+///     will crate pub fn field_name()->&str method
+/// for example:
+///     #[crud_table]
+///     #[derive(Clone, Debug)]
+///     pub struct BizActivity {
+///         pub id: Option<String>,
+///         pub name: Option<String>,
+///         pub delete_flag: Option<i32>,
+///     }
+///     impl_field_name_method!(BizActivity{id,name,delete_flag});
+///
+///    println!("{}",BizActivity::delete_flag());
+#[allow(unused_macros)]
+#[macro_export]
+macro_rules! impl_field_name_method {
+   ($target:ty{$($field_name:ident$(,)?)+}) => {
+         impl $target{
+               $(
+                         #[inline]
+                         pub fn $field_name()->&'static str{
+                               if false{
+                                  |a:$target|{a.$field_name};
+                               }
+                             stringify!($field_name).trim_start_matches("r#")
+                         }
+               )+
+         }
+    };
 }
\ No newline at end of file
